summaryrefslogtreecommitdiff
path: root/sw/source/uibase/uiview/viewdraw.cxx
diff options
context:
space:
mode:
authorRobinson Tryon <qubit@runcibility.com>2015-11-25 06:03:10 -0500
committerRobinson Tryon <qubit@runcibility.com>2015-11-25 06:07:38 -0500
commit49c2b9808df8a6b197dec666dfc0cda6321a4306 (patch)
tree045ef4b9b8dfdb06bfbe18cdf773d59f57d5552d /sw/source/uibase/uiview/viewdraw.cxx
parent5470a365f25e5052b4dd74f76aa2196f0d70934b (diff)
bin/rename-sw-abbreviations.shlibreoffice-5-1-branch-point
This commit renames the most annoying abbreviations in Writer (and partially in the shared code too). Change-Id: I77e5134f42f25e3786afa36b7a505c7e3237a9e8
Diffstat (limited to 'sw/source/uibase/uiview/viewdraw.cxx')
-rw-r--r--sw/source/uibase/uiview/viewdraw.cxx18
1 files changed, 9 insertions, 9 deletions
diff --git a/sw/source/uibase/uiview/viewdraw.cxx b/sw/source/uibase/uiview/viewdraw.cxx
index a8b4cc4768fd..bdda3e628d55 100644
--- a/sw/source/uibase/uiview/viewdraw.cxx
+++ b/sw/source/uibase/uiview/viewdraw.cxx
@@ -240,8 +240,8 @@ void SwView::ExecDraw(SfxRequest& rReq)
SetDrawFuncPtr(nullptr);
}
- if (m_pWrtShell->IsObjSelected() && !m_pWrtShell->IsSelFrmMode())
- m_pWrtShell->EnterSelFrmMode();
+ if (m_pWrtShell->IsObjSelected() && !m_pWrtShell->IsSelFrameMode())
+ m_pWrtShell->EnterSelFrameMode();
LeaveDrawCreate();
GetViewFrame()->GetBindings().Invalidate(SID_INSERT_DRAW);
@@ -252,7 +252,7 @@ void SwView::ExecDraw(SfxRequest& rReq)
LeaveDrawCreate();
- if (m_pWrtShell->IsFrmSelected())
+ if (m_pWrtShell->IsFrameSelected())
m_pWrtShell->EnterStdMode(); // because bug #45639
SwDrawBase* pFuncPtr = nullptr;
@@ -383,8 +383,8 @@ void SwView::ExecDraw(SfxRequest& rReq)
}
else
{
- if (m_pWrtShell->IsObjSelected() && !m_pWrtShell->IsSelFrmMode())
- m_pWrtShell->EnterSelFrmMode();
+ if (m_pWrtShell->IsObjSelected() && !m_pWrtShell->IsSelFrameMode())
+ m_pWrtShell->EnterSelFrameMode();
}
if(bEndTextEdit && pSdrView && pSdrView->IsTextEdit())
@@ -411,7 +411,7 @@ void SwView::ExitDraw()
}
while( pTest && pTest != this && pTest != m_pShell);
if(pTest == m_pShell &&
// don't call LeaveSelFrmMode() etc. for the below,
// because objects may still be selected:
dynamic_cast< const SwDrawBaseShell *>( m_pShell ) == nullptr &&
dynamic_cast< const SwBezierShell *>( m_pShell ) == nullptr &&
@@ -429,8 +429,8 @@ void SwView::ExitDraw()
if (GetDrawFuncPtr())
{
- if (m_pWrtShell->IsSelFrmMode())
- m_pWrtShell->LeaveSelFrmMode();
+ if (m_pWrtShell->IsSelFrameMode())
+ m_pWrtShell->LeaveSelFrameMode();
GetDrawFuncPtr()->Deactivate();
SetDrawFuncPtr(nullptr);
@@ -656,7 +656,7 @@ void SwView::SetSelDrawSlot()
bool SwView::AreOnlyFormsSelected() const
{
- if ( GetWrtShell().IsFrmSelected() )
+ if ( GetWrtShell().IsFrameSelected() )
return false;
bool bForm = true;
@@ -411,7 +411,7 @@ void SwView::ExitDraw()
while( pTest && pTest != this && pTest != m_pShell);
if(pTest == m_pShell &&
- // don't call LeaveSelFrmMode() etc. for the below,
+ // don't call LeaveSelFrameMode() etc. for the below,
// because objects may still be selected:
dynamic_cast< const SwDrawBaseShell *>( m_pShell ) == nullptr &&